==> hs-semigroups-0.8.tbz: lib/ghc-7.0.4/cabal/semigroups-0.8/register.sh <==
#!/bin/sh
echo 'name: semigroups
version: 0.8
id: semigroups-0.8-6e8534570e05e3bb18ad64bd377c39d2

license: BSD3
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
package-url:
description: Haskell 98 semigroups
             .
             In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
exposed-modules: Data.Semigroup Data.List.NonEmpty Numeric.Natural
                 Numeric.Natural.Internal
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/semigroups-0.8
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/semigroups-0.8
              /usr/local/lib
hs-libraries: HSsemigroups-0.8
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/semigroups-0.8/html/semigroups.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/semigroups-0.8/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-semigroups-0.8.3.2_1.tbz: lib/ghc-7.4.1/cabal/semigroups-0.8.3.2/register.sh <==
#!/bin/sh
echo 'name: semigroups
version: 0.8.3.2
id: semigroups-0.8.3.2-01002deb5c1eabd6191c14db9d26c470

license: BSD3
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
package-url:
synopsis: Haskell 98 semigroups
description: Haskell 98 semigroups
             .
             In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
exposed-modules: Data.Semigroup Data.List.NonEmpty Numeric.Natural
                 Numeric.Natural.Internal
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/semigroups-0.8.3.2
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/semigroups-0.8.3.2
              /usr/local/lib
hs-libraries: HSsemigroups-0.8.3.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         containers-0.4.2.1-7c54595400348f577b3b4a45691c5afd
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/semigroups-0.8.3.2/html/semigroups.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/semigroups-0.8.3.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
